********************************************************************************
*	Program: Andrews_Stange_Analysis_Part2.do
*  	This program uses three main data sets:
*		1. 	student_data - is a student level data set which tracks
*			which tracks student's educational outcomes and includes
* 			their demographic information as well as the predicted earnings
*			associated with their major
*		2.	program_level_data - is a programXyear level data set which tracks
*			the characteristics of the courses, sections, instructors, 
*			and students in a given program over time
*		3.	descriptive_regression_results - is the saved output of a 
*			set of descriptive regressions by ventile (of the form:
*			reg `outcome' poor post `controls' for various samples

* The program produces all the figures and tables contained in Andrews & Stange (2019)
* “Price Regulation, Price Discrimination, and Equality of Opportunity in Higher Education: Evidence from Texas”
* Published in American Economic Journal: Economic Policy

********************************************************************************

local DATAPATH "" 
*place the file path for the datasets described above here
local OUTPATH ""
*place the file path for where you want the output to be stored here

********************************************************************************
*			Main Figures
********************************************************************************


	********************************************************************************
	*			Figure 2
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	preserve
	keep if cur_year==2000
	gen order = _n
	gen obs = 1
	collapse (rawsum) count=obs (rawsum) n (mean) mean_pred_earn_test = pred_earn_test  (p25) p25_pred_earn_test = pred_earn_test (p50) p50_pred_earn_test = pred_earn_test (p75) p75_pred_earn_test = pred_earn_test [fw=n], by(major_group)
	
	gsort -p50_pred_earn_test
	gen order = _n
	graph dot p50_pred_earn_raw p50_pred_earn_demo p50_pred_earn_test p50_pred_earn_app if count>= 10 , over(school_name, sort(order) label(labsize(*.75))) title("Predicted Earnings", span)   marker(1, ms(sh) mc(black)) marker(2, ms(th) mc(black)) marker(3, ms(o) mc(black)) marker(4, ms(dh) mc(black)) legend( rows(1) size(*.75) title("Controls") label(1 "Raw") label(2 "Demog") label(3 "Test") label(4 "Application") ) scheme(s1mono)
	graph save "`OUTPATH'/fig_2A.gph", replace
	graph export "`OUTPATH'/fig_2A", replace
	
	restore
	keep if cur_year==2000
	gen order = _n
	gen obs = 1
	collapse (rawsum) count=obs (rawsum) n (mean) mean_pred_earn_test = pred_earn_test  (p25) p25_pred_earn_test = pred_earn_test (p50) p50_pred_earn_test = pred_earn_test (p75) p75_pred_earn_test = pred_earn_test [fw=n], by(school school_name)

	gsort -p50_pred_earn_test
	gen order = _n
	graph dot p50_pred_earn_raw p50_pred_earn_demo p50_pred_earn_test p50_pred_earn_app if count>= 10 , over(school_name, sort(order) label(labsize(*.75))) title("Predicted Earnings", span)   marker(1, ms(sh) mc(black)) marker(2, ms(th) mc(black)) marker(3, ms(o) mc(black)) marker(4, ms(dh) mc(black)) legend( rows(1) size(*.75) title("Controls") label(1 "Raw") label(2 "Demog") label(3 "Test") label(4 "Application") ) scheme(s1mono)
	graph save "`OUTPATH'/fig_2B.gph", replace
	graph export "`OUTPATH'/fig_2B.png", replace

	graph combine "`OUTPATH'/fig_2A.gph" "`OUTPATH'/fig_2B.gph", cols(1) title("Figure 2. Predicted Earnings by Field and Institution, 2000")
	graph export "`OUTPATH'/Figure_2.png", replace
	********************************************************************************
	*			Figure 3
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	*regress tuition on program fixed effects and  year fixed effects for the first quartile of programs
	areg  tuition14_th y2000 y2001 y2002 y2004 y2005 y2006 y2007 y2008 y2009 if sample1==1 & quartile==1,cluster(cohort) absorb(program)

	outreg2 using "`OUTPATH'/fig_3A.xls", excel dec(3) addtext("tuition") append
	*extract year FE coefficients and SEs
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000".."y2002","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004".."y2009", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff1 poor_diff_var1  
	cap drop yearplot
	rename a1 poor_diff1
	rename a2 poor_diff_var1
	cap drop poor_diff_se1 poor_diff_low1 poor_diff_high1
	gen poor_diff_se1=sqrt(poor_diff_var1)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low1=poor_diff1-1.96*poor_diff_se1
	gen poor_diff_high1 = poor_diff1+1.96*poor_diff_se1
	
	************************************************************************
	*regress tuition on program fixed effects and  year fixed effects for the fourth quartile of programs
	areg  tuition14_th y2000 y2001 y2002 y2004 y2005 y2006 y2007 y2008 y2009 if sample1==1 & quartile==4,cluster(cohort) absorb(program)
	outreg2 using "`OUTPATH'/fig_3A.xls", excel dec(3) addtext("tuition") append
	
	*extract year FE coefficients and SEs
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000".."y2002","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004".."y2009", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff4 poor_diff_var4  
	cap drop yearplot
	rename a1 poor_diff4
	rename a2 poor_diff_var4
	cap drop poor_diff_se4 poor_diff_low4 poor_diff_high4
	gen poor_diff_se4=sqrt(poor_diff_var4)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low4=poor_diff4-1.96*poor_diff_se4
	gen poor_diff_high4 = poor_diff4+1.96*poor_diff_se4

	*plot first quartile coefficients
	twoway rcap poor_diff_high1 poor_diff_low1 yearplot, lc(gs12)|| scatter poor_diff1  yearplot, ms(0) mc(black) || rcap poor_diff_high4 poor_diff_low4 yearplot, lc(gs12)|| scatter poor_diff4  yearplot, ms(0) msymbol(triangle) mc(black) ||, legend(label(1 "95% CI") label(2 "Quartile 1") label(4 "Quartile 4") order(2 4 1) size(3)) title("Panel A. Event Study Estimates") xtitle("Year", size(3))  xline(2003.5, lcolor(gs9)) yline(0) scheme(s1mono)
	graph expsaveort "`OUTPATH'/fig_3A.gph", replace
	graph export "`OUTPATH'/fig_3A.png", replace
	
	*plot fourth quartile coefficients
	graph twoway bar coeff vent if venttype=="vent_test" & outcome == "tuition" & variable=="post" & controls == "cohort FE, vent 1 base" & pval <= 5, lc(black) fc(black) barw(.5) yaxis(1) || bar coeff vent if venttype=="vent_test" & outcome == "tuition" & variable=="post" & controls == "cohort FE, vent 1 base" & pval == 10, lc(black) fc(gs10) barw(.5) yaxis(1) || bar coeff vent if venttype=="vent_test" & outcome == "tuition" & variable=="post" & controls == "cohort FE, vent 1 base" & pval > 10, lc(black) fc(white) barw(.5) yaxis(1) || , yline(0) title("Panel B. Interrupted Time Series") xtitle("Ventile of Predicted Program Earnings") ytitle("Tuition Change ($1000s)") legend(off) scheme(s1mono)
	graph save "`OUTPATH'/fig_3B.gph", replace
	graph export "`OUTPATH'/fig_3B.png", replace
	
	*combine q1 and q4 results
	graph combine "`OUTPATH'/fig_3A.gph" "`OUTPATH'/fig_3B.gph", cols(1) title("Figure 3. Sticker Price Change Post-Deregulation, by Program Earnings") subtitle("In-State Juniors, 15 SCH, Fall")
	graph export "`OUTPATH'/Figure_3A.png", replace title("Figure 3. Sticker Price Change Post Deregulation, by Program Earnings")
	
	use "`DATAPATH'/descriptive_regression_results.dta", clear

	graph twoway bar coeff vent if venttype=="vent_test" & outcome == "tuition" & variable=="post" & controls == "cohort FE, vent 1 base" & pval <= 5, lc(black) fc(black) barw(.5) yaxis(1) ||bar coeff vent if venttype=="vent_test" & outcome == "tuition" & variable=="post" & controls == "cohort FE, vent 1 base" & pval == 10, lc(black) fc(gs10) barw(.5) yaxis(1) || bar coeff vent if venttype=="vent_test" & outcome == "tuition" & variable=="post" & controls == "cohort FE, vent 1 base" & pval > 10, lc(black) fc(white) barw(.5) yaxis(1), yline(0) title("Tuition Price Change") subtitle("In-State Juniors, 15 SCH") xtitle("Ventile of Predicted Program Earnings") ytitle("Tuition Change ($1000s)") legend(off) scheme(s1mono)
	graph export "`OUTPATH'/Figure_3B.png", replace
	********************************************************************************
	*			Figure 4
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	*regress predicted earnings on poor indicator, year fixed effects, interaction of poor and year fixed effects, race/ethnic indicators, limited english proficiency indicator and scaled math/reading exit exam scores
	reg  pred_earn_test poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, vce(robust)
	outreg2 using "`OUTPATH'/fig_4.xls", excel dec(3) append
	*extract coefficients and variances for the interaction terms
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff poor_diff_var yearplot
	rename a1 poor_diff
	rename a2 poor_diff_var
	cap drop poor_diff_se poor_diff_low poor_diff_high
	*generate standard errors
	gen poor_diff_se=sqrt(poor_diff_var)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	*generate confidence interval
	gen poor_diff_low=poor_diff-1.96*poor_diff_se
	gen poor_diff_high = poor_diff+1.96*poor_diff_se
	
	twoway rcap poor_diff_high poor_diff_low yearplot, lc(gs12)|| scatter poor_diff yearplot, ms(0) mc(black) ||, legend(label(1 "95% CI") label(2 "Point est") order(2 1) size(3)) scheme(s1mono) title(A. Average Earnings of Program Enrolled in) xtitle("Year", size(3)) ytitle("Poor - Non-Poor", size(3)) xline(2003.5, lcolor(gs9)) yline(0)
	*plot the first panel
	graph save "`OUTPATH'/fig_4_A.gph", replace
	graph export "`OUTPATH'/Figure_4_A.png", replace
	************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	*regress likelihood of appearing in a program from the top ventile on poor indicator, year fixed effects, interaction of poor and year fixed effects, race/ethnic indicators, limited english proficiency indicator and scaled math/reading exit exam scores
	reg  luc_test_20_p poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, vce(robust)
	outreg2 using "`OUTPATH'/fig_4.xls", excel dec(3) append
	*extract coefficients and variances for the interaction terms
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff poor_diff_var yearplot
	rename a1 poor_diff
	rename a2 poor_diff_var
	cap drop poor_diff_se poor_diff_low poor_diff_high
	*generate standard errors
	gen poor_diff_se=sqrt(poor_diff_var)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	*generate confidence interval
	gen poor_diff_low=poor_diff-1.96*poor_diff_se
	gen poor_diff_high = poor_diff+1.96*poor_diff_se
	
	twoway rcap poor_diff_high poor_diff_low yearplot, lc(gs12)|| scatter poor_diff yearplot, ms(0) mc(black) ||, legend(label(1 "95% CI") label(2 "Point est") order(2 1) size(3)) scheme(s1mono) title(B. Likelihood of Enrolling in Top 20% Program) xtitle("Year", size(3)) ytitle("Poor - Non-Poor", size(3)) xline(2003.5, lcolor(gs9)) yline(0)
	*plot the second panel
	graph save "`OUTPATH'/fig_4_B.gph", replace
	graph export "`OUTPATH'/Figure_4_B.png", replace	
	************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	*regress likelihood of appearing in a program from the bottom ventile on poor indicator, year fixed effects, interaction of poor and year fixed effects, race/ethnic indicators, limited english proficiency indicator and scaled math/reading exit exam scores	
	reg  n_luc_test_20_p poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, vce(robust)
	outreg2 using "`OUTPATH'/fig_4.xls", excel dec(3) append
	*extract coefficients and variances for the interaction terms
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff poor_diff_var yearplot
	rename a1 poor_diff
	rename a2 poor_diff_var
	cap drop poor_diff_se poor_diff_low poor_diff_high
	*generate standard errors
	gen poor_diff_se=sqrt(poor_diff_var)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	*generate confidence interval
	gen poor_diff_low=poor_diff-1.96*poor_diff_se
	gen poor_diff_high = poor_diff+1.96*poor_diff_se
	
	twoway rcap poor_diff_high poor_diff_low yearplot, lc(gs12)|| scatter poor_diff yearplot, ms(0) mc(black) ||, legend(label(1 "95% CI") label(2 "Point est") order(2 1) size(3)) scheme(s1mono) title(C. Likelihood of Enrolling in Bottom 20% Program) xtitle("Year", size(3)) ytitle("Poor - Non-Poor", size(3)) xline(2003.5, lcolor(gs9)) yline(0)
	*plot the third panel
	graph save "`OUTPATH'/fig_4_C.gph", replace
	graph export "`OUTPATH'/Figure_4_C.png", replace	

	* combine the first, second, and third panels into a single figure
	graph combine "`OUTPATH'/fig_4_A.gph" "`OUTPATH'/fig_4_B.gph" "`OUTPATH'/fig_4_C.gph", cols(1) title("Figure 4. Event Studey Estimates")
	graph export "`OUTPATH'/figure_4.png", replace
	********************************************************************************
	*			Figure 5
	********************************************************************************
	use "`DATAPATH'/descriptive_regression_results.dta", clear
	*load in results from descriptive regressions
	graph twoway bar coeff vent if venttype=="vent_test" & outcome=="enroll" & variable == "poor" & controls == "Test" , barw(.25)  fcolor(gs6) lcolor(gs6) yaxis(1)||  bar coeff2 vent_testd1 if venttype=="vent_test" & outcome=="enroll" & variable == "post_poor" & controls == "Test" , barw(.25)  fcolor(gs12) lcolor(gs12) yaxis(1)|| scatter coeff2 vent_testd1 if venttype=="vent_test" & outcome=="enroll" & variable == "post_poor" & controls == "Test" & pval <= 10, m(none) mlabel(marker) mlabp(0) mlabg(0)  yaxis(1)|| line pred_earn_test vent if venttype=="vent_test" & controls=="None", yaxis(2)||, yline(0) title("Panel A. Full Controls) legend(order(1 2) label(1 "Poor - NonPoor Enrollment Difference at Baseline") label(2 "Poor - NonPoor Enrollment Difference  Post-Deregulation") rows(2)) xtitle("Ventile of Predicted Program Earnings") ytitle("") scheme(s1mono)
	*plot results with full controls for poor-NonPoor enrollment deifferences
	graph save "`OUTPATH'/fig_5_A.png", replace
	************************************************************************
	graph twoway bar coeff vent if venttype=="vent_test" & outcome=="enroll" & variable == "poor" & controls == "None" , barw(.25)  fcolor(gs6) lcolor(gs6) yaxis(1)|| bar coeff2 vent_testd1 if venttype=="vent_test" & outcome=="enroll" & variable == "post_poor" & controls == "None" , barw(.25)  fcolor(gs12) lcolor(gs12) yaxis(1)|| scatter coeff2 vent_testd1 if venttype=="vent_test" & outcome=="enroll" & variable == "post_poor" & controls == "None" & pval <= 10, m(none) mlabel(marker) mlabp(0) mlabg(0)  yaxis(1)|| line pred_earn_test vent if venttype=="vent_test" & controls=="None", yaxis(2)||, yline(0) title("Panel B. No Controls") legend(order(1 2) label(1 "Poor - NonPoor Enrollment Difference at Baseline") label(2 "Poor - NonPoor Enrollment Difference  Post-Deregulation") rows(2)) xtitle("Ventile of Predicted Program Earnings") ytitle("") scheme(s1mono)
	*plot results with no controls for poor-NonPoor enrollment deifferences
	graph save "`OUTPATH'/fig_5_B.png", replace

	*combine both plots	
	graph combine "`OUTPATH'/fig_5_A.png" "`OUTPATH'/fig_5_B.png", cols(1) title("Initial Difference and Change in Enrollment of Poor vs. Non-Poor Students Across Programs")
	graph export "`OUTPATH'/Figure_5.png", replace
	********************************************************************************
	*			Figure 6
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	reg  grant_tot_fAYr poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor if sample1==1 & quartile==1, vce(robust)
	outreg2 using "`OUTPATH'/fig_6_A1.xls", excel dec(3) addtext("grant_tot_fAYr") replace
	
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff1 poor_diff_var1 
	cap drop yearplot

	rename a1 poor_diff1
	rename a2 poor_diff_var1
	cap drop poor_diff_se1 poor_diff_low1 poor_diff_high1
	gen poor_diff_se1=sqrt(poor_diff_var1)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low1=poor_diff1-1.96*poor_diff_se1
	gen poor_diff_high1 = poor_diff1+1.96*poor_diff_se1
	
	reg  grant_tot_fAYr poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor if sample1==1 & quartile==4, vce(robust)
	outreg2 using "`OUTPATH'/fig_6_A4.xls", excel dec(3) addtext("grant_tot_fAYr") replace
	
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff4 poor_diff_var4 
	cap drop yearplot

	rename a1 poor_diff4
	rename a2 poor_diff_var4
	cap drop poor_diff_se4 poor_diff_low4 poor_diff_high4
	gen poor_diff_se4=sqrt(poor_diff_var4)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low4=poor_diff4-1.96*poor_diff_se4
	gen poor_diff_high4 = poor_diff4+1.96*poor_diff_se4

					
	twoway rcap poor_diff_high1 poor_diff_low1 yearplot, lc(gs12)|| scatter poor_diff1 yearplot, ms(0) mc(black) || rcap poor_diff_high4 poor_diff_low4 yearplot, lc(gs12)|| scatter poor_diff4 yearplot, ms(0) msymbol(triangle) mc(black) ||, legend(label(1 "95% CI") label(2 "Quartile 1") label(4 "Quartile 4") order(2 4 1) size(3)) title("Panel A. Total Grant Aid") xtitle("Year", size(3)) ytitle("Poor - Non-Poor", size(3)) yscale(range(-1000 3000)) ylabel(-1000(1000)3000) xline(2003.5, lcolor(gs9)) yline(0) scheme(s1mono)
	graph export "`OUTPATH'/fig_6A.png", replace
	************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	reg  grant_hb3015_fAYr poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor if sample1==1 & quartile==1, vce(robust)
	outreg2 using "`OUTPATH'/fig_6_B1.xls", excel dec(3) addtext("grant_tot_fAYr") replace
	
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff1 poor_diff_var1 
	cap drop yearplot

	rename a1 poor_diff1
	rename a2 poor_diff_var1
	cap drop poor_diff_se1 poor_diff_low1 poor_diff_high1
	gen poor_diff_se1=sqrt(poor_diff_var1)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low1=poor_diff1-1.96*poor_diff_se1
	gen poor_diff_high1 = poor_diff1+1.96*poor_diff_se1
	
	reg  grant_hb3015_fAYr poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor if sample1==1 & quartile==4, vce(robust)
	outreg2 using "`OUTPATH'/fig_6_B4.xls", excel dec(3) addtext("grant_tot_fAYr") replace
	
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff4 poor_diff_var4 
	cap drop yearplot

	rename a1 poor_diff4
	rename a2 poor_diff_var4
	cap drop poor_diff_se4 poor_diff_low4 poor_diff_high4
	gen poor_diff_se4=sqrt(poor_diff_var4)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low4=poor_diff4-1.96*poor_diff_se4
	gen poor_diff_high4 = poor_diff4+1.96*poor_diff_se4

					
	twoway rcap poor_diff_high1 poor_diff_low1 yearplot, lc(gs12)|| scatter poor_diff1 yearplot, ms(0) mc(black) || rcap poor_diff_high4 poor_diff_low4 yearplot, lc(gs12)|| scatter poor_diff4 yearplot, ms(0) msymbol(triangle) mc(black) ||, legend(label(1 "95% CI") label(2 "Quartile 1") label(4 "Quartile 4") order(2 4 1) size(3)) title("Panel B. HB3015 Grant Aid") xtitle("Year", size(3)) ytitle("Poor - Non-Poor", size(3)) yscale(range(-1000 3000)) ylabel(-1000(1000)3000) xline(2003.5, lcolor(gs9)) yline(0) scheme(s1mono)
	graph export "`OUTPATH'/fig_6B.png", replace	
	************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	*quartile 1
	reg  grant_pell_fAYr poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor if sample1==1 & quartile==1, vce(robust)
	outreg2 using "`OUTPATH'/fig_6_C1.xls", excel dec(3) addtext("grant_tot_fAYr") replace
	
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff1 poor_diff_var1 
	cap drop yearplot

	rename a1 poor_diff1
	rename a2 poor_diff_var1
	cap drop poor_diff_se1 poor_diff_low1 poor_diff_high1
	gen poor_diff_se1=sqrt(poor_diff_var1)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low1=poor_diff1-1.96*poor_diff_se1
	gen poor_diff_high1 = poor_diff1+1.96*poor_diff_se1
	
	*quartile 4
	reg  grant_pell_fAYr poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor if sample1==1 & quartile==4, vce(robust)
	outreg2 using "`OUTPATH'/fig_6_C4.xls", excel dec(3) addtext("grant_tot_fAYr") replace
	
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff4 poor_diff_var4 
	cap drop yearplot

	rename a1 poor_diff4
	rename a2 poor_diff_var4
	cap drop poor_diff_se4 poor_diff_low4 poor_diff_high4
	gen poor_diff_se4=sqrt(poor_diff_var4)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low4=poor_diff4-1.96*poor_diff_se4
	gen poor_diff_high4 = poor_diff4+1.96*poor_diff_se4

					
	twoway rcap poor_diff_high1 poor_diff_low1 yearplot, lc(gs12)|| scatter poor_diff1 yearplot, ms(0) mc(black) || rcap poor_diff_high4 poor_diff_low4 yearplot, lc(gs12)|| scatter poor_diff4 yearplot, ms(0) msymbol(triangle) mc(black) ||, legend(label(1 "95% CI") label(2 "Quartile 1") label(4 "Quartile 4") order(2 4 1) size(3)) title("Panel C. Pell Grant Aid") xtitle("Year", size(3)) ytitle("Poor - Non-Poor", size(3)) yscale(range(-1000 3000)) ylabel(-1000(1000)3000) xline(2003.5, lcolor(gs9)) yline(0) scheme(s1mono)
	graph export "`OUTPATH'/fig_6C.png", replace	
		************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	
	*quartile 1
	reg  grant_txgrant_fAYr poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor if sample1==1 & quartile==1, vce(robust)
	outreg2 using "`OUTPATH'/fig_6_D1.xls", excel dec(3) addtext("grant_tot_fAYr") replace
	
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff1 poor_diff_var1 
	cap drop yearplot

	rename a1 poor_diff1
	rename a2 poor_diff_var1
	cap drop poor_diff_se1 poor_diff_low1 poor_diff_high1
	gen poor_diff_se1=sqrt(poor_diff_var1)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low1=poor_diff1-1.96*poor_diff_se1
	gen poor_diff_high1 = poor_diff1+1.96*poor_diff_se1
	
	*quartile 4
	reg  grant_txgrant_fAYr poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor if sample1==1 & quartile==4, vce(robust)
	outreg2 using "`OUTPATH'/fig_6_B4.xls", excel dec(3) addtext("grant_tot_fAYr") replace
	
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff4 poor_diff_var4 
	cap drop yearplot

	rename a1 poor_diff4
	rename a2 poor_diff_var4
	cap drop poor_diff_se4 poor_diff_low4 poor_diff_high4
	gen poor_diff_se4=sqrt(poor_diff_var4)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low4=poor_diff4-1.96*poor_diff_se4
	gen poor_diff_high4 = poor_diff4+1.96*poor_diff_se4

					
	twoway rcap poor_diff_high1 poor_diff_low1 yearplot, lc(gs12)|| scatter poor_diff1 yearplot, ms(0) mc(black) || rcap poor_diff_high4 poor_diff_low4 yearplot, lc(gs12)|| scatter poor_diff4 yearplot, ms(0) msymbol(triangle) mc(black) ||, legend(label(1 "95% CI") label(2 "Quartile 1") label(4 "Quartile 4") order(2 4 1) size(3)) title("Panel D. TEXAS Grant Aid") xtitle("Year", size(3)) ytitle("Poor - Non-Poor", size(3)) yscale(range(-1000 3000)) ylabel(-1000(1000)3000) xline(2003.5, lcolor(gs9)) yline(0) scheme(s1mono)
	graph export "`OUTPATH'/fig_6D.png", replace

	graph combine "`OUTPATH'/fig_6A.png" "`OUTPATH'/fig_6B.png" "`OUTPATH'/fig_6C.png" "`OUTPATH'/fig_6D.png", cols(2) title("Figure 6. Income-Based Price Discrimination")	
	********************************************************************************
	*			Figure 7
	********************************************************************************
	use "`DATAPATH'/descriptive_regression_results.dta", clear
	* plot results from ventile regressions for enrollment changes to changes in tuition
	twoway scatter coeffenrollpost_poor coefftuitionpost  || lfit coeffenrollpost_poor coefftuitionpost ||, scheme(s1mono) legend(off) ytitle("Change in Poor-NonPoor Share") name(fig_7)
	graph combine fig_7 , rows(1) scheme(s1mono)
	graph export "`OUTPATH'/Figure_7.png", replace
	********************************************************************************
	*			Figure 8
	********************************************************************************
	use "`DATAPATH'/descriptive_regression_results.dta", clear
	twoway scatter coefftotsal_perenroll_trimpost coefftuitionpost  || lfit coefftotsal_perenroll_trimpost coefftuitionpost ||, scheme(s1mono) legend(off) ytitle("Change in Salary per Enrollment") name(fig_8a)		
	* plot results from ventile regressions for salary changes to changes in enrollment
	twoway scatter coeffneedgrantpost_poor coefftuitionpost  || lfit coeffneedgrantpost_poor coefftuitionpost ||, scheme(s1mono) legend(off) ytitle("Change in Need-based Aid") name(fig_8b)
	* plot results for ventile regressions for need-based aid changes to changes in enrollment		
	graph combine fig_8a fig_8b, rows(1) scheme(s1mono) title("Panel A. Resource and Grant Changes with Tuition")
	*combine above plots into first panel
	graph save "`OUTPATH'/fig_8_panel_A.gph", replace
	graph export "`OUTPATH'/Figure_8_Panel_1.png", replace

	twoway scatter coeffenrollpost_poor coefftotsal_perenroll_trimpost  || lfit coeffenrollpost_poor coefftotsal_perenroll_trimpost ||, scheme(s1mono) legend(off) ytitle("Change in Poor-NonPoor Share") name(fig_8c)
	* plot results from ventile regressions for changes in poor-nonpoor shares to changes in salry
	twoway scatter coeffenrollpost_poor coeffneedgrantpost_poor  || lfit coeffenrollpost_poor coeffneedgrantpost_poor ||, scheme(s1mono) legend(off) ytitle("Change in Poor-NonPoor Share") name(fig_8d)
	* plot results from ventile regressions for changes in poor-nonpoor shares to changes in need-based aid	
	graph combine fig_8c fig_8d, rows(1) scheme(s1mono) title("Panel B. Resource and Grant Changes with Enrollment")
	*combine above polots into second panel
	graph save "`OUTPATH'/fig_8_panel_B.gph", replace
	graph export "`OUTPATH'/Figure_8_Panel_1.png", replace
	
	*combine first and second panels into figure 8
	graph combine "`OUTPATH'/fig_8_panel_A.gph" "`OUTPATH'/fig_8_panel_B.gph", cols(1) scheme(s1mono) title("Figure 8. Resource and Grant Changes vs. Tuition and Enrollment Changes")
********************************************************************************
*			Main Tables
********************************************************************************

	********************************************************************************
	*			Table 1
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	log using "`OUTPATH'/logs/table_1.log", text replace
	*summary statistics bysample and poor status
	summ sex black white hispanic asian scaled_math scaled_reading disadvantaged pred_earn_test notenrolled luc_test_10_p luc_test_15_p luc_test_20_p luc_test_25_p n_luc_test_25_p n_luc_test_20_p n_luc_test_15_p n_luc_test_10_p pred_earn_test tuition14_th totsal_perenroll grant_tot_fAYr grant_pell_fAYr grant_hb3015_fAYr grant_txgrant_fAYr grant_tpeg_fAYr grant_seog_fAYr nettuition if sample1Full==1
	summ sex black white hispanic asian  scaled_math scaled_reading disadvantaged pred_earn_test notenrolled luc_test_10_p luc_test_15_p luc_test_20_p luc_test_25_p n_luc_test_25_p n_luc_test_20_p n_luc_test_15_p n_luc_test_10_p pred_earn_test tuition14_th totsal_perenroll grant_tot_fAYr grant_pell_fAYr grant_hb3015_fAYr grant_txgrant_fAYr grant_tpeg_fAYr grant_seog_fAYr nettuition if sample1==1
	summ sex black white hispanic asian  scaled_math scaled_reading disadvantaged pred_earn_test notenrolled luc_test_10_p luc_test_15_p luc_test_20_p luc_test_25_p n_luc_test_25_p n_luc_test_20_p n_luc_test_15_p n_luc_test_10_p pred_earn_test tuition14_th totsal_perenroll grant_tot_fAYr grant_pell_fAYr grant_hb3015_fAYr grant_txgrant_fAYr grant_tpeg_fAYr grant_seog_fAYr nettuition if sample1==1 & poor==1
	summ sex black white hispanic asian  scaled_math scaled_reading disadvantaged pred_earn_test notenrolled luc_test_10_p luc_test_15_p luc_test_20_p luc_test_25_p n_luc_test_25_p n_luc_test_20_p n_luc_test_15_p n_luc_test_10_p pred_earn_test tuition14_th totsal_perenroll grant_tot_fAYr grant_pell_fAYr grant_hb3015_fAYr grant_txgrant_fAYr grant_tpeg_fAYr grant_seog_fAYr nettuition if sample1==1 & poor==0

	log close
	********************************************************************************
	*			Table 2
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear

	reg attend_college poor post post_poor time if sample1Full==1, cluster(cohort)
	* full sample, no controls
	outreg2 poor post post_poor using "`OUTPATH'/table_2.xls", e(N r2) replace
	reg attend_college poor post post_poor asian black white hispanic lep sex scaled_math scaled_reading time if sample1Full==1, cluster(cohort)
	* full sample, full controls
	outreg2  poor post post_poor using "`OUTPATH'/table_2.xls",e(N r2)  append
	reg attend_4yrbal poor post post_poor time if sample1Full==1, cluster(cohort)
	* full sample, no controls
	outreg2 poor post post_poor  using "`OUTPATH'/table_2.xls",e(N r2)  append
	reg attend_4yrbal poor post post_poor asian black white hispanic lep sex scaled_math scaled_reading time if sample1Full==1, cluster(cohort)
	* full sample, full controls
	outreg2 poor post post_poor  using "`OUTPATH'/table_2.xls",e(N r2)  append
	reg pred_earn_test poor post post_poor time if sample1Full==1, cluster(cohort)
	* full sample, no controls
	outreg2 poor post post_poor  using "`OUTPATH'/table_2.xls",e(N r2)  append
	reg pred_earn_test poor post post_poor time if sample1==1, cluster(cohort)
	* college going sample, no controls
	outreg2 poor post post_poor  using "`OUTPATH'/table_2.xls",e(N r2)  append
	reg pred_earn_test poor post post_poor asian black white hispanic lep sex scaled_math scaled_reading time if sample1Full==1, cluster(cohort)
	* full sample, full controls
	outreg2 poor post post_poor  using "`OUTPATH'/table_2.xls",e(N r2)  append
	reg pred_earn_test poor post post_poor asian black white hispanic lep sex scaled_math scaled_reading time if sample1==1, cluster(cohort)
	* college going sample, full controls
	outreg2 poor post post_poor  using "`OUTPATH'/table_2.xls",e(N r2)  append
	*note, this will just produce the coefficients for poor, post, post X poor, obs and R2
	
	********************************************************************************
	*			Table 3
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear

	regress pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*full base controls
	outreg2 poor post_poor using "`OUTPATH'/table_3.xls", excel replace dec(4) e(N)

	areg pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, absorb(highschool) cluster(cohort)
	*full base controls, aborbin HS FEs
	outreg2 poor post_poor using "`OUTPATH'/dtable_3.xls", excel append dec(4) e(N)

	regress pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math *app if sample1==1, cluster(cohort)
	*full base controls, plus application dummies
	outreg2 poor post_poor using "`OUTPATH'/table_3.xls", excel append dec(4) e(N)

	regress pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample2==1, cluster(cohort)
	*full base controls, drop LOS/CS schools
	outreg2 poor post_poor using "`OUTPATH'/table_3.xls", excel append dec(4) e(N)

	regress pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample3==1, cluster(cohort)
	*full base controls, drop LEP students
	outreg2 poor post_poor using "`OUTPATH'/table_3.xls", excel append dec(4) e(N)

	regress pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample4==1, cluster(cohort)
	*full base controls, drop top 30% of each high school graduating cohort
	outreg2 poor post_poor using "`OUTPATH'/table_3.xls", excel append dec(4) e(N)

	regress pred_earn_test time post poor post_poor  asian black white hispanic lep sex scaled_reading scaled_math  if sample5==1, cluster(cohort)
	*full base controls, keep only white students
	outreg2 poor post_poor using "`OUTPATH'/table_3.xls", excel append dec(4) e(N)
	
	regress pred_earn_test time post always_poor post_always_poor  asian black white hispanic lep sex scaled_reading scaled_math  if sample6==1, cluster(cohort)
	*full base controls, poor=always frpl
	outreg2 lways_poor post_always_poor using "`OUTPATH'/table_3.xls", excel append dec(4) e(N) 

	regress pred_earn_test time post pell_poor post_poor_pell  asian black white hispanic lep sex scaled_reading scaled_math  if sample6==1, cluster(cohort)
	*full base controls, poor=pell
	outreg2 pell_poor post_poor_pell using "`OUTPATH'/table_3.xls", excel append dec(4) e(N)

	regress pred_earn_test  time post verypoor verypoor_post asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*full base controls, poor=pell, very poor=0 EFC
	outreg2  post verypoor verypoor_post using "`OUTPATH'/table_3.xls", excel append dec(4) e(N)
	
	regress pred_earn_test_levels time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*full base controls, pred earn in levels
	outreg2 poor post_poor using "`OUTPATH'/table_3.xls, excel append dec(4) e(N)

	********************************************************************************
	*			Table 4
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	regress pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*full base controls
	outreg2 using "`OUTPATH'/table_4.xls", excel replace dec(4) e(N)

	regress pred_earn_test_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*full base controls, predicted earnings at major from junior year
	outreg2 using "`OUTPATH'/table_4.xls", excel append dec(4) e(N)

	regress grad_6yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*full base controls, outcome is graduate within 6-years of beginning college
	outreg2 using "`OUTPATH'/table_4.xls", excel replace dec(4) e(N) 

	regress percent_8 time post poor post_poor   asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*full base controls, outcome is earnings percentile 8-years post high school graduation
	outreg2  using "`OUTPATH'/table_4.xls", excel replace dec(4) e(N) 
			
	regress percent_10 time post poor post_poor   asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*full base controls, outcome is earnings percentile 10-years post high school graduation
	outreg2   using "`OUTPATH'/table_4.xls", excel append dec(4) e(N) 

	regress percent_8 time post poor post_poor attend poorXAttend post_attend post_poorXAttend asian black white hispanic lep sex scaled_reading scaled_math  if sample1Full==1, cluster(cohort)
	*full base controls, outcome is earnings percentile 8-years post high school graduation, interacted with attend
	outreg2 using "`OUTPATH'/table_4.xls", excel replace dec(4) e(N) 
		
	regress percent_10 time post poor post_poor attend poorXAttend post_attend post_poorXAttend asian black white hispanic lep sex scaled_reading scaled_math  if sample1Full==1, cluster(cohort)
	*full base controls, outcome is earnings percentile 10-years post high school graduation, interacted with attend
	outreg2  using "`OUTPATH'/table_4.xls", excel append dec(4) e(N) 
	
		
	********************************************************************************
	*			Table 5
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	
	regress pred_earn_test time post txGrantPoor txGrantPoor_post asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome=predicted earnings, full base controls, using tx grant eligibility to determine poor status, no efc restrictions
	outreg2 txGrantPoor txGrantPoor_post using "`OUTPATH'/table_5.xls", excel replace dec(4) 	
			
	regress pred_earn_test time post txGrantPoor txGrantPoor_post asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1  & EFC_fAYr>=0000 & EFC_fAYr<=10000, cluster(cohort)
	*outcome=predicted earnings, full base controls, using tx grant eligibility to determine poor status, efc bandwidth of 6000
	outreg2 txGrantPoor txGrantPoor_post using "`OUTPATH'/table_5.xls", excel append dec(4) 

	regress pred_earn_test time post txGrantPoor txGrantPoor_post asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1  & EFC_fAYr>=1000 & EFC_fAYr<=7000, cluster(cohort)
	*outcome=predicted earnings, full base controls, using tx grant eligibility to determine poor status, efc bandwidth of 3000
	outreg2 txGrantPoor txGrantPoor_post using "`OUTPATH'/table_5.xls", excel append dec(4) 
	
	regress grant_tot_fAYr time post txGrantPoor txGrantPoor_post asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome=total grant awards, full base controls, using tx grant eligibility to determine poor status, no efc restrictions
	outreg2 txGrantPoor txGrantPoor_post using "`OUTPATH'/table_5.xls", excel append dec(4) 	
			
	regress grant_tot_fAYr time post txGrantPoor txGrantPoor_post asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1  & EFC_fAYr>=0000 & EFC_fAYr<=10000, cluster(cohort)
	*outcome=total grant awards, full base controls, using tx grant eligibility to determine poor status, efc bandwidth of 6000
	outreg2 txGrantPoor txGrantPoor_post using "`OUTPATH'/table_5.xls", excel append dec(4) 
	
	regress grant_tot_fAYr time post txGrantPoor txGrantPoor_post asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1  & EFC_fAYr>=1000 & EFC_fAYr<=7000, cluster(cohort)
	*outcome=total grant awards, full base controls, using tx grant eligibility to determine poor status, efc bandwidth of 3000
	outreg2 txGrantPoor txGrantPoor_post using "`OUTPATH'/table_5.xls", excel append dec(4) 
	
	regress grant_txgrant_fAYr time post txGrantPoor txGrantPoor_post asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome=texas grant awards, full base controls, using tx grant eligibility to determine poor status, no efc restrictions
	outreg2 txGrantPoor txGrantPoor_post using "`OUTPATH'/table_5.xls", excel append dec(4) 	
			
	regress grant_txgrant_fAYr time post txGrantPoor txGrantPoor_post asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1  & EFC_fAYr>=0000 & EFC_fAYr<=10000, cluster(cohort)
	*outcome=texas grant awards, full base controls, using tx grant eligibility to determine poor status, efc bandwidth of 6000
	outreg2 txGrantPoor txGrantPoor_post using "`OUTPATH'/table_5.xls", excel append dec(4) 
				
	regress grant_txgrant_fAYr time post txGrantPoor txGrantPoor_post asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1  & EFC_fAYr>=0000 & EFC_fAYr<=10000, cluster(cohort)
	*outcome=texas grant awards, full base controls, using tx grant eligibility to determine poor status, efc bandwidth of 3000
	outreg2 txGrantPoor txGrantPoor_post using "`OUTPATH'/table_5.xls", excel append dec(4)				
	********************************************************************************
	*			Table 6
	********************************************************************************
	use "`DATAPATH'/program_level_data.dta", clear
	
	areg tuition i.cur_year Post_pearnings_2000_no_controls [aweight=`weight'], absorb(programs) cluster(programs) 
	*outcome=tuition, year FEs
	outreg2 using "`OUTPATH'/table_6.xls, excel replace dec(4)

	areg totsal_perenroll i.cur_year Post_pearnings_2000_no_controls [aweight=`weight'], absorb(programs) cluster(programs) 
	*outcome=total salary per enrollee, year FEs
	outreg2 using "`OUTPATH'/table_6.xls, excel append dec(4)

	areg totfac_perenroll i.cur_year Post_pearnings_2000_no_controls [aweight=`weight'], absorb(programs) cluster(programs) 
	*outcome=total faculty per enrollee, year FEs
	outreg2 using "`OUTPATH'/table_6.xls, excel append dec(4)

	areg FTE_sal i.cur_year Post_pearnings_2000_no_controls [aweight=`weight'], absorb(programs) cluster(programs) 
	*outcome=full time equivalent salary, year FEs
	outreg2 using "`OUTPATH'/table_6.xls, excel append dec(4)

	areg class_size i.cur_year Post_pearnings_2000_no_controls [aweight=`weight'], absorb(programs) cluster(programs) 
	*outcome=average class size, year FEs
	outreg2 using "`OUTPATH'/table_6.xls, excel append dec(4)

	areg tuition time c.pearnings_2000_no_controls#c.time Post Post#c.time Post_pearnings_2000_no_controls c.Post_pearnings_2000_no_controls#c.time , absorb(programs) cluster(programs)
	*outcome=tuition, linear time trends and interactions with post
	outreg2 using "`OUTPATH'/table_6.xls, excel append dec(4)

	areg totsal_perenroll time c.pearnings_2000_no_controls#c.time Post Post#c.time Post_pearnings_2000_no_controls c.Post_pearnings_2000_no_controls#c.time , absorb(programs) cluster(programs)
	*outcome=total salary per enrollee, linear time trends and interactions with post
	outreg2 using "`OUTPATH'/table_6.xls, excel append dec(4)
	
	areg totfac_perenroll time c.pearnings_2000_no_controls#c.time Post Post#c.time Post_pearnings_2000_no_controls c.Post_pearnings_2000_no_controls#c.time , absorb(programs) cluster(programs)
	*outcome=total faculty per enrollee, linear time trends and interactions with post
	outreg2 using "`OUTPATH'/table_6.xls, excel append dec(4)
	
	areg FTE_sal time c.pearnings_2000_no_controls#c.time Post Post#c.time Post_pearnings_2000_no_controls c.Post_pearnings_2000_no_controls#c.time , absorb(programs) cluster(programs)
	*outcome=full time equivalent salary, linear time trends and interactions with post
	outreg2 using "`OUTPATH'/table_6.xls, excel append dec(4)
	
	areg class_size time c.pearnings_2000_no_controls#c.time Post Post#c.time Post_pearnings_2000_no_controls c.Post_pearnings_2000_no_controls#c.time , absorb(programs) cluster(programs)
	*outcome=average class size, linear time trends and interactions with post
	outreg2 using "`OUTPATH'/table_6.xls, excel append dec(4)

********************************************************************************
*			Appendix Figures
********************************************************************************

	********************************************************************************
	*			Figure A1
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear

	keep if cohort==2000
	gen obs = 1
	*collapse summary measures of program quality for 2000 cohort bymajor
	collapse (rawsum) count=obs (rawsum) n (mean) mean_totfac_perenroll = totfac_perenroll  (p25) p25_totfac_perenroll = totfac_perenroll (p50) p50_totfac_perenroll = totfac_perenroll (p75) p75_totfac_perenroll = totfac_perenroll (mean) mean_totsal_perenroll = totsal_perenroll (p25) p25_totsal_perenroll = totsal_perenroll (p50) p50_totsal_perenroll = totsal_perenroll (p75) p75_totsal_perenroll = totsal_perenroll (mean) mean_FTE_salc = FTE_sal (p25) p25_FTE_salc = FTE_sal (p50) p50_FTE_sal = FTE_sal (p75) p75_FTE_sal = FTE_sal (mean) mean_average_enrollment = average_enrollment (p25) p25_average_enrollment = average_enrollment (p50) p50_average_enrollment = average_enrollment (p75) p75_average_enrollment = average_enrollment [fw=n], by(major_group)
	list major_group count n mean_* p50_* if count>= 10

	*sort by total salary
	gsort -p50_totsal_perenroll
	gen order = _n	
	graph dot p25_totsal_perenroll p50_totsal_perenroll p75_totsal_perenroll if count>= 10 , over(major_group, sort(order) label(labsize(*.75))) title("Total Salary per Enrollment", span)   marker(1, ms(oh) mc(black)) marker(2, ms(o) mc(black)) marker(3, ms(oh) mc(black)) legend( rows(1) size(*.75) label(1 "25 Ptile") label(2 "Median") label(3 "75 Ptile") ) scheme(s1mono)
	graph save "`OUTPATH'/fig_A2A.gph", replace
	graph export "`OUTPATH'/fig_A2A.png", replace
	drop order

	*sort by average enrollment
	gsort -p50_average_enrollment
	gen order = _n	
	graph dot p25_average_enrollment p50_average_enrollment p75_average_enrollment if count>= 10 , over(major_group, sort(order) label(labsize(*.75))) title("Average Course Size", span)   marker(1, ms(oh) mc(black)) marker(2, ms(o) mc(black)) marker(3, ms(oh) mc(black)) legend( rows(1) size(*.75) label(1 "25 Ptile") label(2 "Median") label(3 "75 Ptile") ) scheme(s1mono)
	graph save "`OUTPATH'/fig_A2B.gph", replace
	graph export "`OUTPATH'/fig_A2B.png", replace
	drop order
	
	graph combine "`OUTPATH'/fig_A2A.gph" "`OUTPATH'/fig_A2B.gph", cols(1) title("Figure A2. Resource differences by Field, 2000")
	graph export "`OUTPATH'/Figure_A2", replace
	********************************************************************************
	*			Figure A2
	********************************************************************************

	*sort by total faculty per enrollee
	gsort -p50_totfac_perenroll
	gen order = _n	
	graph dot p25_totfac_perenroll p50_totfac_perenroll p75_totfac_perenroll if count>= 10 , over(major_group, sort(order) label(labsize(*.75))) title("Total Faculty per Enrollment", span)   marker(1, ms(oh) mc(black)) marker(2, ms(o) mc(black)) marker(3, ms(oh) mc(black)) legend( rows(1) size(*.75) label(1 "25 Ptile") label(2 "Median") label(3 "75 Ptile") ) scheme(s1mono)
	graph save "`OUTPATH'/fig_A3A.gph", replace
	graph export "`OUTPATH'/fig_A3A.png", replace
	drop order

	* sort by full time equivalent salary
	gsort -p50_FTE_sal
	gen order = _n	
	graph dot p25_FTE_sal p50_FTE_sal p75_FTE_sal if count>= 10 , over(major_group, sort(order) label(labsize(*.75))) title("FTE Salary of Instructors", span)   marker(1, ms(oh) mc(black)) marker(2, ms(o) mc(black)) marker(3, ms(oh) mc(black)) legend( rows(1) size(*.75) label(1 "25 Ptile") label(2 "Median") label(3 "75 Ptile") ) scheme(s1mono)
	graph save "`OUTPATH'/fig_A3B.gph", replace
	graph export "`OUTPATH'/fig_A3B.png", replace
	drop order
	
	graph combine "`OUTPATH'/fig_A3A.gph" "`OUTPATH'/fig_A3B.gph", cols(1) title("Figure A3. Resource differences by Field, 2000")
	graph export "`OUTPATH'/Figure_A3", replace
	********************************************************************************
	*			Figure A3
	********************************************************************************

	********************************************************************************
	*			Figure A4
	********************************************************************************
	use "`OUTPATH'/program_level_data.dta", clear
	preserve
	keep if cur_year==2000
	sum pred_earn_test [fw=n], detail
	*histogram of predicted earnings for the 2000 cohort
	histogram pred_earn_test [fw=n], fraction scheme(s1mono) title("Figure A4. Distriburion of Predicted Program Earnings, 2000") xtitle("Predicted Earnings (Adjusted for Demog, Test)") ytitle("Fraction of 2000 HS Cohort")
	graph export "`OUTPATH'/Figure_A4.png", replace
	restore
	********************************************************************************
	*			Figure A5
	********************************************************************************
	keep if cur_year==2000
	gen obs = 1
	*collapse measures of predicted earnings by major
	collapse (rawsum) count=obs (rawsum) n (mean) mean_pred_earn_raw = pred_earn_test  (p25) p25_pred_earn_raw = pred_earn_raw (p50) p50_pred_earn_raw = pred_earn_raw (p75) p75_pred_earn_raw = pred_earn_raw (mean) mean_pred_earn_demo = pred_earn_demo  (p25) p25_pred_earn_demo = pred_earn_demo (p50) p50_pred_earn_demo = pred_earn_demo (p75) p75_pred_earn_demo = pred_earn_demo (mean) mean_pred_earn_test = pred_earn_test  (p25) p25_pred_earn_test = pred_earn_test (p50) p50_pred_earn_test = pred_earn_test (p75) p75_pred_earn_test = pred_earn_test (mean) mean_pred_earn_app = pred_earn_app  (p25) p25_pred_earn_app = pred_earn_app (p50) p50_pred_earn_app = pred_earn_app (p75) p75_pred_earn_app = pred_earn_app [fw=n], by(major_group)
	list major_group count n mean_* p50_* if count>= 10

	gsort -p50_pred_earn_test
	gen order = _n
	graph dot p50_pred_earn_raw p50_pred_earn_demo p50_pred_earn_test p50_pred_earn_app if count>= 10 , over(major_group, sort(order) label(labsize(*.75)))   marker(1, ms(sh) mc(black)) marker(2, ms(th) mc(black)) marker(3, ms(o) mc(black)) marker(4, ms(dh) mc(black)) legend( rows(1) size(*.75) title("Controls") label(1 "Raw") label(2 "Demog") label(3 "Test") label(4 "Application") ) scheme(s1mono)
	graph save "`OUTPATH'/fig_A5A.gph", replace
	graph export "`OUTPATH'/fig_A5A.png", replace

	restore,preserve
	keep if cur_year==2000
	gen obs = 1
	*collapse measures of predicted earnings by school
	collapse (rawsum) count=obs (rawsum) n (mean) mean_pred_earn_raw = pred_earn_test  (p25) p25_pred_earn_raw = pred_earn_raw (p50) p50_pred_earn_raw = pred_earn_raw (p75) p75_pred_earn_raw = pred_earn_raw (mean) mean_pred_earn_demo = pred_earn_demo  (p25) p25_pred_earn_demo = pred_earn_demo (p50) p50_pred_earn_demo = pred_earn_demo (p75) p75_pred_earn_demo = pred_earn_demo (mean) mean_pred_earn_test = pred_earn_test  (p25) p25_pred_earn_test = pred_earn_test (p50) p50_pred_earn_test = pred_earn_test (p75) p75_pred_earn_test = pred_earn_test (mean) mean_pred_earn_app = pred_earn_app  (p25) p25_pred_earn_app = pred_earn_app (p50) p50_pred_earn_app = pred_earn_app (p75) p75_pred_earn_app = pred_earn_app [fw=n], by(school school_name)
	list school_name count n mean_* p50_* if count>= 10


	gsort -p50_pred_earn_test
	gen order = _n
	graph dot p50_pred_earn_raw p50_pred_earn_demo p50_pred_earn_test p50_pred_earn_app if count>= 10 , over(school_name, sort(order) label(labsize(*.75)))   marker(1, ms(sh) mc(black)) marker(2, ms(th) mc(black)) marker(3, ms(o) mc(black)) marker(4, ms(dh) mc(black)) legend( rows(1) size(*.75) title("Controls") label(1 "Raw") label(2 "Demog") label(3 "Test") label(4 "Application") ) scheme(s1mono)
	graph save "`OUTPATH'/fig_A5B.gph", replace
	graph export "`OUTPATH'/fig_A5B.png", replace

	graph combine "`OUTPATH'/fig_A5A.gph" "`OUTPATH'/fig_A5B.gph", cols(1) title("Figure A5. Earnings Differences by Field and Institutions, Robustness to Controls")
	graph export "`OUTPATH'/Figure_A5.png", replace
	********************************************************************************
	*			Figure A6
	********************************************************************************
	restore
	egen vent_cohort_poor=group(cohort vent_test poor)
	collapse (rawsum) count=obs (rawsum) n (mean) cohort (mean) vent_test (mean) poor, by(vent_cohort_poor)
	keep if cohort==2000 | cohort==2008
	twoway bar n vent_test if poor==0 & cohort==2000 || bar n vent_test if poor==0 & cohort==2008, title("Panel A. Non-Poor Students") ytitle("Fraction of Non-Poor HS Graduates") xtitle("Ventile of Program Earning Potential (Demog, Test)") scheme(s1mono) legend(label(1 "2000") label(2 "2008"))
	graph save "`OUTPATH'/fig_A6A.gph", replace
	graph export "`OUTPATH'/fig_A6A.png", replace
	
	twoway bar n vent_test if poor==1 & cohort==2000 || bar n vent_test if poor==1 & cohort==2008, title("Panel A. Non-Poor Students") ytitle("Fraction of Poor HS Graduates") xtitle("Ventile of Program Earning Potential (Demog, Test)") scheme(s1mono) legend(label(1 "2000") label(2 "2008"))
	graph save "`OUTPATH'/fig_A6B.gph", replace
	graph export "`OUTPATH'/fig_A6B.png", replace	
	
	graph combine "`OUTPATH'/fig_A6A.gph" "`OUTPATH'/fig_A6B.gph", cols(1) title("Figure A6. Distribution of Students Across Programs, 2000 and 2008 Cohorts")
	graph export "`OUTPATH'/Figure_A6.png", replace	
	********************************************************************************
	*			Figure A7
	********************************************************************************
	use "`DATAPATH'/descriptive_regression_results.dta", clear
	* plot enrollment changes by ventile
	graph twoway bar coeff vent if venttype=="vent_test" & outcome=="enroll" & variable == "post_poor" & controls == "None" , barw(.25)|| bar coeff vent_testd1 if venttype=="vent_test" & outcome=="enroll" & variable == "post_poor" & controls == "Demog" , barw(.25)|| bar coeff vent_testd2 if venttype=="vent_test" & outcome=="enroll" & variable == "post_poor" & controls == "Test", barw(.25) || bar coeff vent_testd3 if venttype=="vent_test" & outcome=="enroll" & variable == "post_poor" & controls == "App" , barw(.25)|| bar coeff vent_testd4 if venttype=="vent_test" & outcome=="enroll" & variable == "post_poor" & controls == "HS FE" , barw(.25)||, yline(0) title("Figure A7. Change in Enrollment of Poor and Non-Poor Students Across Programs)  xtitle("Ventile of Predicted Program Earnings") ytitle("") scheme(s1mono) legend(title("Controls", size(*.75)) rows(2) label(3 "Test+Demog") label(1 "None") label(2 "Demog") label(4 "App") label(5 "HS FE") size(*.75))
	graph export "`OUTPATH'/Figure_A7.png", replace
	********************************************************************************
	*			Figure A8
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	*predicted earning event study, in levels, by poor and non-poor
	reg  pred_earn_test poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1 , vce(robust)
	*extract coefficients and variances
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff poor_diff_var yearplot
	rename a1 poor_diff
	rename a2 poor_diff_var
	cap drop poor_diff_se poor_diff_low poor_diff_high
	gen poor_diff_se=sqrt(poor_diff_var)
	
	matrix d=e(b)',vecdiag(e(V))'
	matrix d2=d["y2001".."y2003","y1".."r1"]
	matrix d3=(0,.)
	
	matrix d4=d["y2004".."y2009","y1".."r1"]
	matrix D=d3\d2\d4
	svmat D, names("e")
	cap drop nonpoor_levels nonpoor_levels_se yearplot
	rename e1 nonpoor_levels
	rename e2 nonpoor_levels_var
	cap drop nonpoor_levels_se nonpoor_levels_low nonpoor_levels_high
	gen nonpoor_levels_se=sqrt(nonpoor_levels_var)

	matrix h=e(b)',vecdiag(e(V))'
	matrix h2=h["poor","y1".."r1"]
	matrix H=h2\h2\h2\h2\h2\h2\h2\h2\h2\h2
	matrix list H
		matrix f=B+D+H
	svmat f, names("g")
	cap drop poor_levels poor_levels_se
	rename g1 poor_levels
	rename g2 poor_levels_var
	cap drop poor_levels_se poor_levels_low poor_levels_high
	gen poor_levels_se=sqrt(poor_levels_var)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low=poor_diff-1.96*poor_diff_se
	gen poor_diff_high = poor_diff+1.96*poor_diff_se
	gen nonpoor_levels_low=nonpoor_levels-1.96*nonpoor_levels_se
	gen nonpoor_levels_high=nonpoor_levels+1.96*nonpoor_levels_se
	gen poor_levels_low=poor_levels-1.96*poor_levels_se
	gen poor_levels_high=poor_levels+1.96*poor_levels_se
			
	twoway rcap poor_levels_high poor_levels_low yearplot, lc(gs12)|| scatter poor_levels  yearplot, ms(0) mc(black) || rcap nonpoor_levels_high nonpoor_levels_low yearplot || scatter nonpoor_levels yearplot|| , legend(label(1 "95% CI") label(2 "Poor") label(4 "Non Poor") label(5 "Poor - NonPoor") order(2 4 1) size(3)) title("A. Average Earnings of Program Enrolled in") xtitle("Year", size(3))  xline(2003.5, lcolor(gs9)) yline(0) scheme(s1mono)
	graph sae "`OUTPATH'/fig_A8A.gph", replace
	graph export "`OUTPATH'/Figure_A8_A.png", replace

	restore,preserve
	************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	*likelihood of appearing in a top 20 program event study, in levels, by poor and non-poor
	reg  luc_test_20_p poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1 , vce(robust)

	*extract coefficients and variances
	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff poor_diff_var yearplot
	rename a1 poor_diff
	rename a2 poor_diff_var
	cap drop poor_diff_se poor_diff_low poor_diff_high
	gen poor_diff_se=sqrt(poor_diff_var)
	
	matrix d=e(b)',vecdiag(e(V))'
	matrix d2=d["y2001".."y2003","y1".."r1"]
	matrix d3=(0,.)
	
	matrix d4=d["y2004".."y2009","y1".."r1"]
	matrix D=d3\d2\d4
	svmat D, names("e")
	cap drop nonpoor_levels nonpoor_levels_se yearplot
	rename e1 nonpoor_levels
	rename e2 nonpoor_levels_var
	cap drop nonpoor_levels_se nonpoor_levels_low nonpoor_levels_high
	gen nonpoor_levels_se=sqrt(nonpoor_levels_var)

	matrix h=e(b)',vecdiag(e(V))'
	matrix h2=h["poor","y1".."r1"]
	matrix H=h2\h2\h2\h2\h2\h2\h2\h2\h2\h2
	matrix list H
		matrix f=B+D+H

	svmat f, names("g")
	cap drop poor_levels poor_levels_se
	rename g1 poor_levels
	rename g2 poor_levels_var
	cap drop poor_levels_se poor_levels_low poor_levels_high
	gen poor_levels_se=sqrt(poor_levels_var)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low=poor_diff-1.96*poor_diff_se
	gen poor_diff_high = poor_diff+1.96*poor_diff_se
	gen nonpoor_levels_low=nonpoor_levels-1.96*nonpoor_levels_se
	gen nonpoor_levels_high=nonpoor_levels+1.96*nonpoor_levels_se
	gen poor_levels_low=poor_levels-1.96*poor_levels_se
	gen poor_levels_high=poor_levels+1.96*poor_levels_se
	
	
	twoway rcap poor_levels_high poor_levels_low yearplot, lc(gs12)|| scatter poor_levels  yearplot, ms(0) mc(black) || rcap nonpoor_levels_high nonpoor_levels_low yearplot || scatter nonpoor_levels yearplot|| , legend(label(1 "95% CI") label(2 "Poor") label(4 "Non Poor") label(5 "Poor - NonPoor") order(2 4 1) size(3)) title("B. Likelihood of Enrolling in Top 20% Program") xtitle("Year", size(3))  xline(2003.5, lcolor(gs9)) yline(0) scheme(s1mono)
	graph save "`OUTPATH'/fig_A8B.gph", replace
	graph export "`OUTPATH'/Figure_A8_B.png", replace

	restore,preserve
	************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	reg  n_luc_test_20_p poor y2001 y2002 y2003 y2004 y2005 y2006 y2007 y2008 y2009 y2000_poor y2001_poor y2002_poor y2004_poor y2005_poor y2006_poor y2007_poor y2008_poor y2009_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1 , vce(robust)

	matrix b = e(b)',vecdiag(e(V))'
	matrix b2=b["y2000_poor".."y2002_poor","y1".."r1"]
	matrix b3= (0,.)
	
	matrix b4=b["y2004_poor".."y2009_poor", "y1".."r1"]
	matrix B=b2\b3\b4
	matrix list B
	svmat B, names("a")
	cap drop poor_diff poor_diff_var yearplot
	rename a1 poor_diff
	rename a2 poor_diff_var
	cap drop poor_diff_se poor_diff_low poor_diff_high
	gen poor_diff_se=sqrt(poor_diff_var)
	
	matrix d=e(b)',vecdiag(e(V))'
	matrix d2=d["y2001".."y2003","y1".."r1"]
	matrix d3=(0,.)
	
	matrix d4=d["y2004".."y2009","y1".."r1"]
	matrix D=d3\d2\d4
	svmat D, names("e")
	cap drop nonpoor_levels nonpoor_levels_se yearplot
	rename e1 nonpoor_levels
	rename e2 nonpoor_levels_var
	cap drop nonpoor_levels_se nonpoor_levels_low nonpoor_levels_high
	gen nonpoor_levels_se=sqrt(nonpoor_levels_var)
	matrix h=e(b)',vecdiag(e(V))'
	matrix h2=h["poor","y1".."r1"]
	matrix H=h2\h2\h2\h2\h2\h2\h2\h2\h2\h2
	matrix list H
		matrix f=B+D+H

	svmat f, names("g")
	cap drop poor_levels poor_levels_se
	rename g1 poor_levels
	rename g2 poor_levels_var
	cap drop poor_levels_se poor_levels_low poor_levels_high
	gen poor_levels_se=sqrt(poor_levels_var)
	
	gen yearplot=2000+_n-1 if _n<=11
	label var yearplot "Year"
	gen poor_diff_low=poor_diff-1.96*poor_diff_se
	gen poor_diff_high = poor_diff+1.96*poor_diff_se
	gen nonpoor_levels_low=nonpoor_levels-1.96*nonpoor_levels_se
	gen nonpoor_levels_high=nonpoor_levels+1.96*nonpoor_levels_se
	gen poor_levels_low=poor_levels-1.96*poor_levels_se
	gen poor_levels_high=poor_levels+1.96*poor_levels_se
	
	twoway rcap poor_levels_high poor_levels_low yearplot, lc(gs12)|| scatter poor_levels  yearplot, ms(0) mc(black) || rcap nonpoor_levels_high nonpoor_levels_low yearplot || scatter nonpoor_levels yearplot|| , legend(label(1 "95% CI") label(2 "Poor") label(4 "Non Poor") label(5 "Poor - NonPoor") order(2 4 1) size(3)) title("C. Likelihood of Enrolling in Bottom 20% Program") xtitle("Year", size(3))  xline(2003.5, lcolor(gs9)) yline(0) scheme(s1mono)
	graph save "`OUTPATH'/fig_A8C.gph", replace
	graph export "`OUTPATH'/Figure_A8_C.png", replace
	
	graph combine "`OUTPATH'/fig_A8A.gph" "`OUTPATH'/fig_A8B.gph" "`OUTPATH'/fig_A8C.gph", cols(1) title("Figure A8. Event-Study Estimates in Levels")
	********************************************************************************
	*			Figure A9
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	twoway line vent_mean_nettuition_need cohort if poor==1 || line vent_mean_nettuition_need cohort if poor==0, legend(label(1 "Poor") label(2 "Non-Poor")) ytitle("Thousands of Dollars")  by(vent_test, title("Figure A9. Net Tuition Over Time, Separately by Program Earnings Ventile")) xline(2004)  scheme(s1mono)
	graph export "`OUTPATH'/Figure_A9.png", replace 
	********************************************************************************
	*			Figure A10
	********************************************************************************
	use "`DATAPATH'/descriptive_regression_results.dta", clear

	twoway scatter coefftotsal_perenroll_trimpost coefftuitionpost  || lfit coefftotsal_perenroll_trimpost coefftuitionpost ||, scheme(s1mono) legend(off) ytitle("Change in Salary per Enrollment") name(fig_A10A)
	* plot coefficients for ventile regressions of salary per enrollment to changes in tuition
	twoway scatter coeffFTE_salpost coefftuitionpost  || lfit coeffFTE_salpost coefftuitionpost ||, scheme(s1mono) legend(off) ytitle("Change in FTE Salary") name(fig_A10B)
	* plot coefficients for ventile regressions of full time equivalent salary to changes in tuition	
	twoway scatter coeffaverage_enrollmentpost coefftuitionpost  || lfit coeffaverage_enrollmentpost coefftuitionpost ||, scheme(s1mono) legend(off) ytitle("Change in Class Size") name(fig_A10C)
	* plot coefficients for ventile regressions of class size to changes in tuition
	twoway scatter coefftotfac_perenroll_trimpost coefftuitionpost  || lfit coefftotfac_perenroll_trimpost coefftuitionpost ||, scheme(s1mono) legend(off) ytitle("Change in Faculty per Enrollment") name(fig_A10D)
	* plot coefficients for ventile regressions of faculty per enrollee to changes in tuition
	
	graph combine fig_A10A fig_A10B fig_A10C fig_A10D, rows(2) scheme(s1mono)
	* combine above figures
	graph export "`OUTPATH'/Figure_A10.png", replace
	********************************************************************************
	*			Figure A11
	********************************************************************************
	use "`DATAPATH'/descriptive_regression_results.dta", clear
	
	*scatter plots of different grant awardamounts by tuition, with a line of best fit

	twoway scatter coeffhb3015_amtpost_poor coefftuitionpost  || lfit coeffhb3015_amtpost_poor coefftuitionpost ||, scheme(s1mono) legend(off) ytitle("Change in HB3015 Grants") name(fig_A11A)

	twoway scatter coeffpell_amtpost_poor coefftuitionpost  || lfit coeffpell_amtpost_poor coefftuitionpost ||, scheme(s1mono) legend(off) ytitle("Change in Pell Grants") name(fig_A11B)
	
	twoway scatter coefftxgrant_amtpost_poor coefftuitionpost  || lfit coefftxgrant_amtpost_poor coefftuitionpost ||, scheme(s1mono) legend(off) ytitle("Change in Texas Grants") name(fig_A11C)
	
	twoway scatter coefftpeg_amtpost_poor coefftuitionpost  || lfit coefftpeg_amtpost_poor coefftuitionpost ||, scheme(s1mono) legend(off) ytitle("Change in TPEG Grants") name(fig_A11D)
	
	graph combine fig_A11A fig_A11B fig_A11C fig_A11D, rows(2) scheme(s1mono) ycommon
	graph export "`OUTPATH'/Figure_A11.png", replace

	********************************************************************************
	*			Figure D1
	********************************************************************************
	use "`OUTPATH'/student_data.dta", clear
	*grab regression results for enrollment changes on ventile
	twoway line enroll_diff vent_test , lc(gs12)|||| ci_hi ci_low vent_test , lpattern(.), scheme(s1mono) title("A. Overall") subtitle("Percent changes in annual enrollment of students")  legend(label(2 "95% CI") label(1 "Ovearall"))
	*plot enrollment changes overall by ventile
	graph save "`OUTPATH'/fig_D1A.gph", replace
	graph export "`OUTPATH'/fig_D1A.png", replace
	
	twoway line non_res vent_test if res==0, lc(gs12)|||| ci_hi_nonres ci_low _nonresvent_test if res==0, lpattern(.), scheme(s1mono) title("A. Overall") subtitle("Percent changes in annual enrollment of students")  legend(label(2 "95% CI") label(1 "Non-residents"))
	*plot enrollment changes for non-residents by ventile
	graph save "`OUTPATH'/fig_D1B.gph", replace
	graph export "`OUTPATH'/fig_D1B.png", replace
	
	graph combine "`OUTPATH'/fig_D1A.gph" "`OUTPATH'/fig_D1B.gph", cols(1) title("Figure D1: Ventile-Specific annual enrollment time trend")
	graph export "`OUTPATH'/Figure_D1.png", replace
	********************************************************************************
	*			Figure D2
	********************************************************************************
	use "`OUTPATH'/student_data.dta", clear
	*grab regression results for enrollment changes on ventile in the post deregulation period
	
	twoway line post vent_test if cohort>=2005, lc(gs12)|||| ci_hi_post ci_low_post vent_test if cohort>=2005, lpattern(.), scheme(s1mono) title("A. Overall") subtitle("Percent changes in annual enrollment of students")  legend(label(2 "95% CI") label(1 "Ovearall"))
	*plot enrollment changes overall by ventile
	graph save "`OUTPATH'/fig_D2A.gph", replace
	graph export "`OUTPATH'/fig_D2A.png", replace
	
	twoway line non_res_post vent_test if res==0 & cohort>=2005, lc(gs12)|||| ci_hi_non_res_post ci_low_non_res_post vent_test if res==0 & cohort>=2005, lpattern(.), scheme(s1mono) title("A. Overall") subtitle("Percent changes in annual enrollment of students")  legend(label(2 "95% CI") label(1 "Non-residents"))
	*plot enrollment changes for non-residents by ventile in the post deregulation period
	graph save "`OUTPATH'/fig_D2B.gph", replace
	graph export "`OUTPATH'/fig_D2B.png", replace
	
	graph combine "`OUTPATH'/fig_D2A.gph" "`OUTPATH'/fig_D2B.gph", cols(1) title("Figure D2: Ventile-Specific post-deregulation enrollment change")
	graph export "`OUTPATH'/Figure_D2.png", replace
		
********************************************************************************
*			Appendix Tables
********************************************************************************


	********************************************************************************
	*			Table A1
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	*Panel A comes from the THECB report on the TEXAS grant, the below code produces the percentages for panel B
	forvalues YYYY=2000(1)2009{
		sum efc_0 efc_2000 efc_4000 efc_6000 efc_above if cohort==`YYYY' & sample1==1
	}
	********************************************************************************
	*			Table A2
	********************************************************************************
	use "`DATAPATH'/department_data.dta", clear
	sum tuition lower upper totfac_perenroll_5 newhire_perenroll_5 totsal_perenroll_5 courses_perenroll_5 sections_perenroll_5 FTE_sal prof_sal assoc_sal assist_sal newhire_sal class_size pred_earn_raw pred_earn_test 
	*summary stats, all programs and years
	codebook program
	* use this to determine the number of unique programs
	sum tuition lower upper totfac_perenroll_5 newhire_perenroll_5 totsal_perenroll_5 courses_perenroll_5 sections_perenroll_5 FTE_sal prof_sal assoc_sal assist_sal newhire_sal class_size pred_earn_raw pred_earn_test if cohort==2009
	*summary stats, all programs in 2009
	codebook program if cohort==2009
	* use this to determine the number of unique programs
	sum tuition lower upper totfac_perenroll_5 newhire_perenroll_5 totsal_perenroll_5 courses_perenroll_5 sections_perenroll_5 FTE_sal prof_sal assoc_sal assist_sal newhire_sal class_size pred_earn_raw pred_earn_test if cohort==2009 & high_price==0
	*summary stats, low-price programs in 2009
	codebook program if cohort==2009 & high_price==0
	* use this to determine the number of unique programs
	sum tuition lower upper totfac_perenroll_5 newhire_perenroll_5 totsal_perenroll_5 courses_perenroll_5 sections_perenroll_5 FTE_sal prof_sal assoc_sal assist_sal newhire_sal class_size pred_earn_raw pred_earn_test if cohort==2009 & high_price==1
	*summary stats, high-price programs in 2009
	codebook program if cohort==2009 & high_price==1
	* use this to determine the number of unique programs

	
	********************************************************************************
	*			Table A3
	********************************************************************************
	use "`DATAPATH'/department_data.dta", clear
	log using "`OUTPATH'/table_A3.txt" text, replace
	*sort by level of predicted earnings, with controls for demographics and test scores
	sort pred_earn_test
	list first_school first_major pred_earn_test undergrads if topten_test==1
	*list school, major, predicted earnings premium, and number of students for top 10 programs by level of predicted earnings, with controls for demographics and test scores
	list first_school first_major pred_earn_test undergrads if bottomten_test==1
	*list school, major, predicted earnings premium, and number of students for top 10 programs by level of predicted earnings, with controls for demographics and test scores
	sort pred_earn_app
	*sort by level of predicted earnings, with controls for demographics, test scores, and application/admissions behavior
	list first_school first_major pred_earn_test undergrads if topten_app==1
	*list school, major, predicted earnings premium, and number of students for top 10 programs by level of predicted earnings, with controls for demographics, test scores, and application/admissions behavior
	list first_school first_major pred_earn_test undergrads if bottomten_app==1
	*list school, major, predicted earnings premium, and number of students for top 10 programs by level of predicted earnings, with controls for demographics, test scores, and application/admissions behavior
	log close
	********************************************************************************
	*			Table A4
	********************************************************************************
	use "`DATAPATH'/department_data.dta", clear
	log using "`OUTPATH'/table_A4.txt" text, replace
	list first_school first_major pred_earn_test undergrads if vent_test==20 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 20
	list first_school first_major pred_earn_test undergrads if vent_test==19 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 19
	list first_school first_major pred_earn_test undergrads if vent_test==18 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 18
	list first_school first_major pred_earn_test undergrads if vent_test==17 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 17
	list first_school first_major pred_earn_test undergrads if vent_test==16 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 16
	list first_school first_major pred_earn_test undergrads if vent_test==15 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 15
	list first_school first_major pred_earn_test undergrads if vent_test==14 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 14
	list first_school first_major pred_earn_test undergrads if vent_test==13 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 13
	list first_school first_major pred_earn_test undergrads if vent_test==12 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 12
	list first_school first_major pred_earn_test undergrads if vent_test==11 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 11
	list first_school first_major pred_earn_test undergrads if vent_test==10 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 10
	list first_school first_major pred_earn_test undergrads if vent_test==9 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 9
	list first_school first_major pred_earn_test undergrads if vent_test==8 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 8
	list first_school first_major pred_earn_test undergrads if vent_test==7 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 7
	list first_school first_major pred_earn_test undergrads if vent_test==6 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 6
	list first_school first_major pred_earn_test undergrads if vent_test==5 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 5
	list first_school first_major pred_earn_test undergrads if vent_test==4 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 4
	list first_school first_major pred_earn_test undergrads if vent_test==3 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 3
	list first_school first_major pred_earn_test undergrads if vent_test==2 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 2
	list first_school first_major pred_earn_test undergrads if vent_test==1 & cohort==2000
	*list school, major, predicted earnings premium, and number of students for ventile 1

	log close
	********************************************************************************
	*			Table A5
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	*table_A5_A is the first panel, A5_B is the middle panel, and A5_C is the final panel of table A5
	regress pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*cluster on cohort
	estout using "`OUTPATH'/table_A5_A.xls",  replace cells(b p)

	regress pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(poorXcohort)
	*cluster on cohort X poor
	estout using  "`OUTPATH'/table_A5_A.xls",  replace cells(b p)

	regress pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(first_school)
	*cluster on school
	estout using  "`OUTPATH'/table_A5_A.xls",  replace cells(b p)
	
	bootstrap, rep(500): regress pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*bootstrap, cluster on cohort
	estout using  "`OUTPATH'/table_A5_B.xls",  replace cells(b p)	

	bootstrap, rep(500): regress pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(poorXcohort)
	*bootstrap, cluster on cohort X poor
	estout using  "`OUTPATH'/table_A5_B.xls",  replace cells(b p)

	bootstrap, rep(500): regress pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(first_school)
	*bootstrap, cluster on school
	estout using  "`OUTPATH'/table_A5_B.xls",  replace cells(b p)

	cgmwildboot pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(majorXcohort) bootcluster(cohort) reps(500) seed(12345)
	*wild-bootstrap, cluster on cohort
	estout using  "`OUTPATH'/table_A5_C.xls",  append cells(b p) 

	cgmwildboot pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(poorXcohort) bootcluster(poorXcohort) reps(500) seed(12345)
	*wild-bootstrap, cluster on cohort X poor
	estout using "`OUTPATH'/table_A5_C.xls",  append cells(b p)

	cgmwildboot pred_earn_test time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(first_school) bootcluster(first_school) reps(500) seed(12345)
	*wild-bootstrap, cluster on school
	estout using "`OUTPATH'/table_A5_C.xls", append cells(b p)

	********************************************************************************
	*			Table A6
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	*Panel A
 
	regress pred_earn_test_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- predicted earnings, full controls full sample
	outreg2 poor post_poor using "`OUTPATH'/table_A6_A.xls", excel replace dec(4) 
	
	regress pred_earn_test_2yr time post poor post_poor if sample1==1, cluster(cohort)
	*outcome- predicted earnings, full sample no controls
	outreg2 poor post_poor using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 	
	
	regress pred_earn_test_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample2==1, cluster(cohort)
	*outcome- predicted earnings, full controls drop los/cs
	outreg2 poor post_poor using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 

	regress pred_earn_test_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample3==1, cluster(cohort)
	*outcome- predicted earnings, full controls drop lep
	outreg2 poor post_poor using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 

	regress pred_earn_test_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample4==1, cluster(cohort)
	*outcome- predicted earnings, full controls drop top 30%
	outreg2 always_poor post_always_poor using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 

	regress pred_earn_test_2yr time post always_poor post_always_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- predicted earnings, full controls poor=always FRPL
	outreg2 always_poor post_always_poor  using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 
	
	regress pred_earn_test_2yr time post ever_poor post_ever_poor  asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- predicted earnings, full controls poor=ever FRPL
	outreg2 ever_poor post_ever_poor using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 

	*Panel B
	
	regress luc_test_10_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- top 10% program, full controls full sample
	outreg2 poor post_poor using "`OUTPATH'/table_A6_B.xls", excel replace  dec(4) 

	regress luc_test_10_p_2yr time post poor post_poor if sample1==1, cluster(cohort)
	*outcome- top 10% program, no controls drop los/cs
	outreg2 poor post_poor using "`OUTPATH'/table_A6_B.xls", excel appenddec(4)  
	
	regress luc_test_10_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample2==1, cluster(cohort)
	*outcome- top 10% program, full controls drop los/cs
	outreg2 poor post_poor using "`OUTPATH'/table_A6_B.xls", excel append dec(4) 

	regress luc_test_10_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample3==1, cluster(cohort)
	*outcome- top 10% program, full controls drop lep
	outreg2 poor post_poor using "`OUTPATH'/table_A6_B.xls", excel append dec(4) 

	regress luc_test_10_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample4==1, cluster(cohort)
	*outcome- top 10% program, full controls drop top 30%
	outreg2 poor post_poor using "`OUTPATH'/table_A6_B.xls", excel append dec(4) 

	regress luc_test_10_p_2yr time post always_poor post_always_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- top 10% program, full controls poor=always FRPL
	outreg2 always_poor post_always_poor  using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 
	
	regress luc_test_10_p_2yr time post ever_poor post_ever_poor  asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- top 10% program, full controls poor=ever FRPL
	outreg2 ever_poor post_ever_poor using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 


	*Panel C
	
	regress luc_test_20_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- top 20% program, full controls full sample
	outreg2 poor post_poor using "`OUTPATH'/table_A6_C.xls", excel replace dec(4) 

	regress luc_test_20_p_2yr time post poor post_poor if sample1==1, cluster(cohort)
	*outcome- top 20% program, full sample no controls
	outreg2 poor post_poor using "`OUTPATH'/table_A6_C.xls", excel append dec(4)  

	regress luc_test_20_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample2==1, cluster(cohort)
	*outcome- top 20% program, full controls drop los/cs
	outreg2 poor post_poor using "`OUTPATH'/table_A6_C.xls", excel append dec(4) 

	regress luc_test_20_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample3==1, cluster(cohort)
	*outcome- top 20% program, full controls drop lep
	outreg2 poor post_poor using "`OUTPATH'/table_A6_C.xls", excel append dec(4) 

	regress luc_test_20_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample4==1, cluster(cohort)
	*outcome- top 20% program, full controls drop top 30%
	outreg2 poor post_poor using "`OUTPATH'/table_A6_C.xls", excel append dec(4) 

	regress luc_test_20_p_2yr time post always_poor post_always_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- top 20% program, full controls poor=always FRPL
	outreg2 always_poor post_always_poor  using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 
	
	regress luc_test_20_p_2yr time post ever_poor post_ever_poor  asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- top 20% program, full controls poor=ever FRPL
	outreg2 ever_poor post_ever_poor using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 


	*Panel D
	regress n_luc_test_20_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- bottom 20% program, full controls full sample
	outreg2 poor post_poor using "`OUTPATH'/table_A6_D.xls", excel replace dec(4) 

	regress n_luc_test_20_p_2yr time post poor post_poor if sample1==1, cluster(cohort)
	*outcome- bottom 20% program, full sample no controls
	outreg2 poor post_poor using "`OUTPATH'/table_A6_D.xls", excel append dec(4)  
	
	regress n_luc_test_20_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample2==1, cluster(cohort)
	*outcome- bottom 20% program, full controls drop los/cs
	outreg2 poor post_poor using "`OUTPATH'/table_A6_D.xls", excel append dec(4) 

	regress n_luc_test_20_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample3==1, cluster(cohort)
	*outcome- bottom 20% program, full controls drop lep
	outreg2 poor post_poor using "`OUTPATH'/table_A6_D.xls", excel append dec(4) 

	regress n_luc_test_20_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample4==1, cluster(cohort)
	*outcome- bottom 20% program, full controls drop top 30%
	outreg2 poor post_poor using "`OUTPATH'/table_A6_D.xls", excel append dec(4) 

	regress n_luc_test_20_p_2yr time post always_poor post_always_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- bottom 20% program, full controls poor=always FRPL
	outreg2 always_poor post_always_poor  using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 
	
	regress n_luc_test_20_p_2yr time post ever_poor post_ever_poor  asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- bottom 20% program, full controls poor=ever FRPL
	outreg2 ever_poor post_ever_poor using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 


	*Panel E
	regress n_luc_test_10_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- bottom 20% program, full controls full sample
	outreg2 poor post_poor using "`OUTPATH'/table_A6_E.xls", excel replace dec(4) 
	
	regress n_luc_test_10_p_2yr time post poor post_poor if sample1==1, cluster(cohort)
	*outcome- bottom 20% program, full sample no controls
	outreg2 poor post_poor using "`OUTPATH'/table_A6_E.xls", excel append dec(4)  
	
	regress n_luc_test_10_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample2==1, cluster(cohort)
	*outcome- bottom 20% program, full controls drop los/cs
	outreg2 poor post_poor using "`OUTPATH'/table_A6_E.xls", excel append dec(4) 

	regress n_luc_test_10_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample3==1, cluster(cohort)
	*outcome- bottom 20% program, full controls drop lep
	outreg2 poor post_poor using "`OUTPATH'/table_A6_E.xls", excel append dec(4) 

	regress n_luc_test_10_p_2yr time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math   if sample4==1, cluster(cohort)
	*outcome- bottom 20% program, full controls drop top 30%
	outreg2 poor post_poor using "`OUTPATH'/table_A6_E.xls", excel append dec(4) 

	regress n_luc_test_10_p_2yr time post always_poor post_always_poor asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- bottom 20% program, full controls poor=always FRPL
	outreg2 always_poor post_always_poor  using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 
	
	regress n_luc_test_10_p_2yr time post ever_poor post_ever_poor  asian black white hispanic lep sex scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- bottom 20% program, full controls poor=ever FRPL
	outreg2 ever_poor post_ever_poor using "`OUTPATH'/table_A6_A.xls", excel append dec(4) 

	********************************************************************************
	*			Table A7
	********************************************************************************
	use "`DATAPATH'/school_data.dta", clear
	*individual data, collapsed by school
	list first_school undergrad undergrad_p if top30==1
	list first_school undergrad undergrad_p if top30==0
	list first_school undergrad undergrad_p 

	********************************************************************************
	*			Table A8
	********************************************************************************
	use "`DATAPATH'/major_data.dta", clear
	*individual data, collapsed by first major
	list first_school undergrad undergrad_p if top30==1
	list first_school undergrad undergrad_p if top30==0
	list first_school undergrad undergrad_p 
	
	********************************************************************************
	*			Table A9
	********************************************************************************
	use "`DATAPATH'/individual_data.dta", clear
	regress pred_earn_test time post poor post_poor if sample1==1, cluster(cohort)
	*outcome- program predicted earnings, no controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_A.xls", excel replace dec(4) 
	regress pred_earn_test time post poor post_poor asian black white hispanic lep if sample1==1, cluster(cohort)
	*outcome- program predicted earnings, demographic controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_A.xls", excel append dec(4) 
	regress pred_earn_test time post poor post_poor asian black white hispanic lep scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- program predicted earnings, demographic and test controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_A.xls", excel append dec(4) 
	regress pred_earn_test time post poor post_poor asian black white hispanic lep scaled_reading scaled_math *app if sample1==1, cluster(cohort)
	*outcome- program predicted earnings, demographic, test, and application controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_A.xls", excel append dec(4) 
	areg pred_earn_test time post poor post_poor asian black white hispanic lep scaled_reading scaled_math *app if sample1==1, absorb(highschool) 
	*outcome- program predicted earnings, demographic, test, application, and high school controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_A.xls", excel append dec(4) 

	regress pred_earn_test_school time post poor post_poor if sample1==1, cluster(cohort)
	*outcome- program predicted earnings, no controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_B.xls", excel replace dec(4) 
	regress pred_earn_test_school time post poor post_poor asian black white hispanic lep if sample1==1, cluster(cohort)
	*outcome- program predicted earnings, demographic controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_B.xls", excel append dec(4) 
	regress pred_earn_test_school time post poor post_poor asian black white hispanic lep scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- program predicted earnings, demographic and test controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_B.xls", excel append dec(4) 
	regress pred_earn_test_school time post poor post_poor asian black white hispanic lep scaled_reading scaled_math *app if sample1==1, cluster(cohort)
	*outcome- program predicted earnings, demographic, test, and application controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_B.xls", excel append dec(4) 
	areg pred_earn_test_school time post poor post_poor asian black white hispanic lep scaled_reading scaled_math *app if sample1==1, absorb(highschool) 
	*outcome- program predicted earnings, demographic, test, application, and high school controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_B.xls", excel append dec(4) 
	
	regress pred_earn_test_major time post poor post_poor if sample1==1, cluster(cohort)
	*outcome- program predicted earnings, demographic controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_C.xls", excel replace dec(4) 
	regress pred_earn_test_major time post poor post_poor asian black white hispanic lep if sample1==1, cluster(cohort)
	*outcome- program predicted earnings, demographic and test controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_C.xls", excel append dec(4) 
	regress pred_earn_test_major time post poor post_poor asian black white hispanic lep scaled_reading scaled_math  if sample1==1, cluster(cohort)
	*outcome- program predicted earnings, demographic, test, and application controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_C.xls", excel append dec(4) 
	regress pred_earn_test_major time post poor post_poor asian black white hispanic lep scaled_reading scaled_math *app if sample1==1, cluster(cohort)
	*outcome- program predicted earnings, no controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_C.xls", excel append dec(4) 
	areg pred_earn_test_major time post poor post_poor asian black white hispanic lep scaled_reading scaled_math *app if sample1==1, absorb(highschool) 
	*outcome- program predicted earnings, demographic, test, application, and high school controls
	outreg2 poor post_poor using "`OUTPATH'/table_A9_C.xls", excel append dec(4) 
		
	
	********************************************************************************
	*			Table A10
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	*note, this is a pretty messy way of doing it, since each school generates its own excel file
	local school_abr "ang lam mwsu pv shsu sfasu sul tare tamui tamu tamug tamuc tamucc tamuk tsu tsusm tt twu uta ut utb utd utep utsa utt utpb utpa uh uhd unt wtamu"
	foreach w of local school_abr{
		reg `w'_enroll post poor post_poor asian black white hispanic lep sex , cluster(cohort)
		*outcome pr(enroll)
		outreg2 post_poor using "`OUTPATH'/table_A10_`w'.xls", excel replace dec(4)
		reg `w'_app  post poor post_poor asian black white hispanic lep sex, cluster(cohort)
		*outcome pr(apply)
		outreg2 post_poor using "`OUTPATH'/table_A10_`w'.xls", excel append dec(4)
		reg `w'_ad  post poor post_poor asian black white hispanic lep sex if `w'_app==1, cluster(cohort)
		outreg2 post_poor using "`OUTPATH'/table_A10_`w'.xls", excel append dec(4)
		*outcome pr(admit|apply)
	}
	********************************************************************************
	*			Table A11
	********************************************************************************
	use "`DATAPATH'/student_data.dta", clear
	log using "`OUTPATH'/table_A11.txt", text replace
	*note, this is a pretty messy way of doing it, since each school's data apears consecutively
	local school_abr "ang lam mwsu pv shsu sfasu sul tare tamui tamu tamug tamuc tamucc tamuk tsu tsusm tt twu uta ut utb utd utep utsa utt utpb utpa uh uhd unt wtamu"
	foreach w of local school_abr{
		sum pred_earn_test if school_abv==`w'
		sum `w'_enroll `w'_app 
		sum `w'_ad if `w'_app==1
		sum `w'_enroll if `w'_ad==1
	}
	log close


	********************************************************************************
	*			Table D1
	********************************************************************************
	use "`OUTPATH'/student_data.dta", clear
	*use resident data
	reg enroll time c.time#c.pred_earn_test post post_pred_earn_test, cluster(cohort)
	*full sample
	outreg2 using "`OUTPATH'/table_D1.xls", excel replace dec(4)
	reg enroll time c.time#c.pred_earn_test post post_pred_earn_test, cluster(cohort) if res==0
	*non-resident sample
	outreg2 using "`OUTPATH'/table_D1.xls", excel append dec(4)
